@@ -19,10 +19,10 @@ import org.eclipse.jface.action.Action;
 import org.eclipse.jface.viewers.StructuredSelection;
 
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.bean.PropertyConstant;
-import com.clustercontrol.composite.PropertySheet;
+import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.PropertySheet;
 
 /**
  * プロパティをコピーするクライアント側アクションクラス<BR>
@@ -56,10 +56,10 @@ public class CopyPropertyAction extends Action {
 	public void run() {
 		//選択されたプロパティを取得
 		StructuredSelection selection = (StructuredSelection) m_viewer
-		.getSelection();
+				.getSelection();
 		Property property = (Property) selection.getFirstElement();
 
-		if (property.getCopy() == PropertyConstant.COPY_OK) {
+		if (property.getCopy() == PropertyDefineConstant.COPY_OK) {
 			//選択されたプロパティのコピーを作成
 			Property clone = PropertyUtil.copy(property);
 
