@@ -12,14 +12,13 @@ import javax.xml.ws.soap.SOAPBinding;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.accesscontrol.etc.action.LoginAction;
 import com.clustercontrol.ws.access.AccessEndpointService;
 import com.clustercontrol.ws.calendar.CalendarEndpointService;
 import com.clustercontrol.ws.collectiverun.CollectiveRunEndpointService;
 import com.clustercontrol.ws.collectmaster.PerformanceCollectMasterEndpointService;
 import com.clustercontrol.ws.collector.CollectorEndpointService;
 import com.clustercontrol.ws.jobmanagement.JobEndpointService;
-import com.clustercontrol.ws.jobmap.JobMapEndpointService;
+import com.clustercontrol.ws.jobmanagement.JobMapEndpointService;
 import com.clustercontrol.ws.mailtemplate.MailTemplateEndpointService;
 import com.clustercontrol.ws.maintenance.MaintenanceEndpointService;
 import com.clustercontrol.ws.monitor.MonitorEndpointService;
@@ -72,7 +71,7 @@ public class EndpointManager {
 		 * endpointList.contains(lastSuccessEndpoint)は必ずtrueになる。
 		 */
 		private ArrayList<HashMap<String, EndpointSetting>> endpointList =
-			new ArrayList<HashMap<String, EndpointSetting>>();
+				new ArrayList<HashMap<String, EndpointSetting>>();
 		private HashMap<String, EndpointSetting> lastSuccessEndpoint = null;
 
 		private void add(HashMap<String, EndpointSetting> endpointMap) {
@@ -162,10 +161,7 @@ public class EndpointManager {
 
 		public Object getEndpoint() {
 			// ログインしていない場合は、ここでログインする。
-			if (username == null || password == null) {
-				LoginAction action = new LoginAction();
-				action.run(null);
-			}
+			LoginManager.login();
 
 			if (endpoint != null) {
 				// set latest timeout
@@ -250,7 +246,7 @@ public class EndpointManager {
 				try {
 					tmpEndpointService = new JobMapEndpointService(
 							new URL(urlStr),
-							new QName("http://jobmap.ws.clustercontrol.com", tmpKey));
+							new QName("http://jobmanagement.ws.clustercontrol.com", tmpKey));
 				} catch (MalformedURLException e) {
 					m_log.warn("getEndpoint():JobMapEndpointService, " + e.getMessage(), e);
 				}
@@ -389,14 +385,14 @@ public class EndpointManager {
 		}
 	}
 
-	public static void init(String user, String pass, String managerAddressList, 
+	public static void init(String user, String pass, String managerAddressList,
 			int httpConnectTimeout, int httpRequestTimeout) throws MalformedURLException {
 		username = user;
 		password = pass;
 		endpointList = new EndpointList();
 		m_httpConnectTimeout = httpConnectTimeout;
 		m_httpRequestTimeout = httpRequestTimeout;
-		
+
 		for (String managerAddress : managerAddressList.split(",")) {
 
 			// TODO ユーザ/パスワードチェックを実装する必要あり。
@@ -430,14 +426,12 @@ public class EndpointManager {
 		bp.getRequestContext().put(BindingProvider.USERNAME_PROPERTY, user);
 		bp.getRequestContext().put(BindingProvider.PASSWORD_PROPERTY, password);
 
-		// bp.getRequestContext().put(BindingProviderProperties.CONNECT_TIMEOUT, 10*1000);
-		// bp.getRequestContext().put(BindingProviderProperties.REQUEST_TIMEOUT, 60*1000);
 		bp.getRequestContext().put("com.sun.xml.internal.ws.connect.timeout", m_httpConnectTimeout * 1000);
 		bp.getRequestContext().put("com.sun.xml.internal.ws.request.timeout", m_httpRequestTimeout * 1000);
-		if (m_log.isDebugEnabled()) {
-			m_log.debug("ws timeout updated : connectTimeout = " + m_httpConnectTimeout + ", requestTimeout = " + m_httpRequestTimeout + "");
+		if (m_log.isTraceEnabled()) {
+			m_log.trace("ws timeout updated : connectTimeout = " + m_httpConnectTimeout + ", requestTimeout = " + m_httpRequestTimeout + "");
 		}
-		
+
 		((SOAPBinding)bp.getBinding()).setMTOMEnabled(true);
 	}
 
