@@ -33,12 +33,8 @@ public class StringBinder {
 	private Map<String, String> param = new HashMap<String, String>();
 	private static final String _postfixOriginal = ":original";
 
-	/**
-	 * コンストラクタ
-	 */
-	public StringBinder() {
-
-	}
+	private static String replaceChar = "?";
+	private static boolean replace = false;
 
 	/**
 	 * 置換のマッピングを引数としたコンストラクタ
@@ -52,10 +48,30 @@ public class StringBinder {
 		}
 	}
 
+	/**
+	 * 
+	 * @param replaceChar
+	 */
+	public static void setReplaceChar(String replaceChar) {
+		log.info("setReplaceChar() StringBinder Invalid Chars replace to [" + replaceChar + "]");
+		StringBinder.replaceChar = replaceChar;
+	}
+
+	/**
+	 * 
+	 * @param replace
+	 */
+	public static void setReplace(boolean replace) {
+		log.info("setReplace() StringBinder Invalid Chars replace is " + replace);
+		StringBinder.replace = replace;
+	}
+
 	/**
 	 * 変数#[KEY]をVALUEに置き換えた文字列を返す。
 	 * 
 	 * @param str 変数が含まれる文字列
+	 * @param replace 特殊文字(ascii 0x00-0x20,0x7f)を空白に置換するか\x01のような表記にするか
+	 *         4.0と同じ動作にする場合はfalse。
 	 * @return 変数が置換された文字列
 	 */
 	public String bindParam(String str) {
@@ -105,11 +121,19 @@ public class StringBinder {
 			for (byte ascii = 0; ascii < 0x20; ascii++) {
 				byte[] byteCode = { ascii };
 				String strReplace = new String(byteCode);
-				str = str.replace(strReplace, "\\x" + Integer.toHexString(ascii).toUpperCase());
+				if (replace) {
+					str = str.replace(strReplace, replaceChar);
+				} else {
+					str = str.replace(strReplace, "\\x" + Integer.toHexString(ascii).toUpperCase());
+				}
 			}
 			byte[] byteCode = { 0x7F };
 			String strReplace = new String(byteCode);
-			str = str.replace(strReplace, "\\x" + Integer.toHexString(0x7F).toUpperCase());
+			if (replace) {
+				str = str.replace(strReplace, replaceChar);
+			} else {
+				str = str.replace(strReplace, "\\x" + Integer.toHexString(0x7F).toUpperCase());
+			}
 
 			ret = str;
 		}
@@ -122,17 +146,24 @@ public class StringBinder {
 
 	public static void main(String[] args) {
 
-		String str = "foo #[PARAM] bar #[ESCAPE:escape] #[NOTFOUND] foo";
+		String str = "foo #[PARAM] bar #[ESCAPE] #[NOTFOUND] foo";
 
 		Map<String, String> param = new HashMap<String, String>();
 		param.put("PARAM", "foofoo");
-		param.put("ESCAPE", "foo 'bar' \"foo\" `echo aaa` \\ bar");
+		byte[] byteCode = { 0x10 };
+
+		param.put("ESCAPE", "foo 'bar' \"foo\" `echo aaa` \\ bar" +
+				" [" + new String(byteCode) + "], [" + new String(byteCode) + "]");
 
 		StringBinder binder = new StringBinder(param);
-		System.out.println("ORIGINAL : " + str);
 		System.out.println("PARAM : " + param);
-		System.out.println("BINDED : " + binder.bindParam(str));
-
+		System.out.println("ORIGINAL : " + str);
+		System.out.println("BINDED   : " + binder.bindParam(str));
+		StringBinder.setReplace(true);
+		System.out.println("BINDED   : " + binder.bindParam(str));
+		StringBinder.setReplaceChar("$");
+		StringBinder.setReplace(true);
+		System.out.println("BINDED   : " + binder.bindParam(str));
 	}
 
 }
