@@ -46,18 +46,20 @@ public class GetCalendarListTableDefine {
 	/** 説明 */
 	public static final int DESCRIPTION = 4;
 
+	/** オーナーロール */
+	public static final int OWNER_ROLE = 5;
+
 	/** 作成者 */
-	public static final int CREATOR_NAME = 5;
+	public static final int CREATOR_NAME = 6;
 
 	/** 作成日時 */
-	public static final int CREATE_TIME = 6;
+	public static final int CREATE_TIME = 7;
 
 	/** 更新者 */
-	public static final int MODIFIER_NAME = 7;
+	public static final int MODIFIER_NAME = 8;
 
 	/** 更新日時 */
-	public static final int MODIFY_TIME = 8;
-
+	public static final int MODIFY_TIME = 9;
 	/** 初期表示時ソートカラム */
 	public static final int SORT_COLUMN_INDEX = CALENDAR_ID;
 
@@ -88,6 +90,8 @@ public class GetCalendarListTableDefine {
 						TableColumnInfo.NONE, 140, SWT.LEFT));
 		tableDefine.add(DESCRIPTION,
 				new TableColumnInfo(Messages.getString("description", locale), TableColumnInfo.NONE, 150, SWT.LEFT));
+		tableDefine.add(OWNER_ROLE,
+				new TableColumnInfo(Messages.getString("owner.role.id", locale), TableColumnInfo.NONE, 130, SWT.LEFT));
 		tableDefine.add(CREATOR_NAME,
 				new TableColumnInfo(Messages.getString("creator.name", locale), TableColumnInfo.NONE, 100, SWT.LEFT));
 		tableDefine.add(CREATE_TIME,
@@ -96,6 +100,7 @@ public class GetCalendarListTableDefine {
 				new TableColumnInfo(Messages.getString("modifier.name", locale), TableColumnInfo.NONE, 100, SWT.LEFT));
 		tableDefine.add(MODIFY_TIME,
 				new TableColumnInfo(Messages.getString("update.time", locale), TableColumnInfo.NONE, 140, SWT.LEFT));
+
 		return tableDefine;
 	}
 }
\ No newline at end of file
