@@ -31,7 +31,6 @@ import org.eclipse.swt.widgets.Combo;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
-import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.bean.DataRangeConstant;
@@ -40,13 +39,14 @@ import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.SizeConstant;
 import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.composite.NumberVerifyListener;
-import com.clustercontrol.composite.PositiveNumberVerifyListener;
-import com.clustercontrol.composite.TimeVerifyListener;
+import com.clustercontrol.composite.action.NumberVerifyListener;
+import com.clustercontrol.composite.action.PositiveNumberVerifyListener;
+import com.clustercontrol.composite.action.TimeVerifyListener;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.jobmanagement.bean.ConditionTypeConstant;
 import com.clustercontrol.jobmanagement.bean.OperationConstant;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.util.TimeTo48hConverter;
 import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
 
 /**
@@ -57,41 +57,41 @@ import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
  */
 public class EndDelayComposite extends Composite {
 	/** 終了遅延セッション開始後の時間用チェックボタン */
-	protected Button m_sessionCondition = null;
+	private Button m_sessionCondition = null;
 	/** 終了遅延セッション開始後の時間の値用テキスト*/
-	protected Text m_sessionValue = null;
+	private Text m_sessionValue = null;
 	/** 終了遅延ジョブ開始後の時間用チェックボタン */
-	protected Button m_jobCondition = null;
+	private Button m_jobCondition = null;
 	/** 終了遅延ジョブ開始後の時間の値用テキスト */
-	protected Text m_jobValue = null;
+	private Text m_jobValue = null;
 	/** 終了遅延時刻用チェックボタン */
-	protected Button m_timeCondition = null;
+	private Button m_timeCondition = null;
 	/** 終了遅延時刻の値用テキスト */
-	protected Text m_timeValue = null;
+	private Text m_timeValue = null;
 	/** 終了遅延判定対象の条件関係 AND用ラジオボタン */
-	protected Button m_andCondition = null;
+	private Button m_andCondition = null;
 	/** 終了遅延判定対象の条件関係 OR用ラジオボタン */
-	protected Button m_orCondition = null;
+	private Button m_orCondition = null;
 	/**  終了遅延通知用チェックボタン */
-	protected Button m_notifyCondition = null;
+	private Button m_notifyCondition = null;
 	/**  終了遅延通知重要度用コンボボックス */
-	protected Combo m_notifyPriority = null;
+	private Combo m_notifyPriority = null;
 	/** 終了遅延操作用チェックボタン */
-	protected Button m_operationCondition = null;
+	private Button m_operationCondition = null;
 	/** 終了遅延操作用グループ */
-	protected Group m_operationConditionGroup = null;
+	private Group m_operationConditionGroup = null;
 	/** 終了遅延操作種別用コンボボックス */
-	protected Combo m_operationType = null;
+	private Combo m_operationType = null;
 	/** 終了遅延操作終了値用テキスト */
-	protected Text m_operationValue = null;
+	private Combo m_operationStatus = null;
+	/** 終了遅延操作終了値用テキスト */
+	private Text m_operationValue = null;
 	/** 終了遅延用チェックボタン */
-	protected Button m_endDelayCondition = null;
+	private Button m_endDelayCondition = null;
 	/** 終了遅延用グループ */
-	protected Group m_endDelayConditionGroup = null;
+	private Group m_endDelayConditionGroup = null;
 	/** ジョブ待ち条件情報 */
-	protected JobWaitRuleInfo m_waitRule = null;
-	/** シェル */
-	protected Shell m_shell = null;
+	private JobWaitRuleInfo m_waitRule = null;
 
 	/**
 	 * コンストラクタ
@@ -106,7 +106,6 @@ public class EndDelayComposite extends Composite {
 	public EndDelayComposite(Composite parent, int style, boolean isFileJob) {
 		super(parent, style);
 		initialize(isFileJob);
-		m_shell = this.getShell();
 	}
 
 	/**
@@ -177,7 +176,7 @@ public class EndDelayComposite extends Composite {
 		composite.setLayout(rowLayout);
 		m_sessionCondition = new Button(composite, SWT.CHECK);
 		m_sessionCondition.setText(Messages.getString("time.after.session.start") + " : ");
-		m_sessionCondition.setLayoutData(new RowData(180,
+		m_sessionCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_sessionCondition.addSelectionListener(new SelectionListener() {
 			@Override
@@ -209,7 +208,7 @@ public class EndDelayComposite extends Composite {
 						update();
 					}
 				}
-		);
+				);
 
 		//ジョブ開始後の時間
 		composite = new Composite(group, SWT.NONE);
@@ -219,7 +218,7 @@ public class EndDelayComposite extends Composite {
 		composite.setLayout(rowLayout);
 		m_jobCondition = new Button(composite, SWT.CHECK);
 		m_jobCondition.setText(Messages.getString("time.after.job.start") + " : ");
-		m_jobCondition.setLayoutData(new RowData(180,
+		m_jobCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_jobCondition.addSelectionListener(new SelectionListener() {
 			@Override
@@ -251,7 +250,7 @@ public class EndDelayComposite extends Composite {
 						update();
 					}
 				}
-		);
+				);
 
 		//時刻
 		composite = new Composite(group, SWT.NONE);
@@ -261,7 +260,7 @@ public class EndDelayComposite extends Composite {
 		composite.setLayout(rowLayout);
 		m_timeCondition = new Button(composite, SWT.CHECK);
 		m_timeCondition.setText(Messages.getString("wait.rule.time.example") + " : ");
-		m_timeCondition.setLayoutData(new RowData(180,
+		m_timeCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_timeCondition.addSelectionListener(new SelectionListener() {
 			@Override
@@ -292,7 +291,7 @@ public class EndDelayComposite extends Composite {
 						update();
 					}
 				}
-		);
+				);
 
 		//判定対象の条件関係
 		group = new Group(m_endDelayConditionGroup, SWT.NONE);
@@ -382,15 +381,19 @@ public class EndDelayComposite extends Composite {
 
 					int type = getSelectOperationName(m_operationType);
 					if (type == OperationConstant.TYPE_STOP_AT_ONCE) {
+						m_operationStatus.setEnabled(false);
 						m_operationValue.setEnabled(false);
 					} else if(type == OperationConstant.TYPE_STOP_SUSPEND){
+						m_operationStatus.setEnabled(false);
 						m_operationValue.setEnabled(false);
 					} else if(type == OperationConstant.TYPE_STOP_SET_END_VALUE){
+						m_operationStatus.setEnabled(true);
 						m_operationValue.setEnabled(true);
 					}
 					m_operationConditionGroup.setEnabled(true);
 				} else {
 					m_operationType.setEnabled(false);
+					m_operationStatus.setEnabled(false);
 					m_operationValue.setEnabled(false);
 					m_operationConditionGroup.setEnabled(false);
 				}
@@ -436,10 +439,13 @@ public class EndDelayComposite extends Composite {
 
 				int type = getSelectOperationName(check);
 				if (type == OperationConstant.TYPE_STOP_AT_ONCE) {
+					m_operationStatus.setEnabled(false);
 					m_operationValue.setEnabled(false);
 				} else if(type == OperationConstant.TYPE_STOP_SUSPEND){
+					m_operationStatus.setEnabled(false);
 					m_operationValue.setEnabled(false);
 				} else if(type == OperationConstant.TYPE_STOP_SET_END_VALUE){
+					m_operationStatus.setEnabled(true);
 					m_operationValue.setEnabled(true);
 				}
 				update();
@@ -451,6 +457,24 @@ public class EndDelayComposite extends Composite {
 			}
 		});
 
+
+		//操作の終了状態
+		composite = new Composite(m_operationConditionGroup, SWT.NONE);
+		rowLayout = new RowLayout();
+		rowLayout.type = SWT.HORIZONTAL;
+		rowLayout.spacing = 10;
+		composite.setLayout(rowLayout);
+		label = new Label(composite, SWT.NONE);
+		label.setText(Messages.getString("end.status") + " : ");
+		label.setLayoutData(new RowData(100,
+				SizeConstant.SIZE_LABEL_HEIGHT));
+		m_operationStatus = new Combo(composite, SWT.CENTER | SWT.READ_ONLY);
+		m_operationStatus.setLayoutData(new RowData(100,
+				SizeConstant.SIZE_COMBO_HEIGHT));
+		m_operationStatus.add(EndStatusConstant.STRING_NORMAL);
+		m_operationStatus.add(EndStatusConstant.STRING_WARNING);
+		m_operationStatus.add(EndStatusConstant.STRING_ABNORMAL);
+
 		//操作の終了値
 		composite = new Composite(m_operationConditionGroup, SWT.NONE);
 		rowLayout = new RowLayout();
@@ -473,7 +497,7 @@ public class EndDelayComposite extends Composite {
 						update();
 					}
 				}
-		);
+				);
 
 		label = new Label(composite, SWT.NONE);
 		label.setLayoutData(new RowData(70, SizeConstant.SIZE_LABEL_HEIGHT));
@@ -514,23 +538,7 @@ public class EndDelayComposite extends Composite {
 	 * 
 	 * @see com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo
 	 */
-	@SuppressWarnings("unchecked")
 	public void reflectWaitRuleInfo() {
-
-		// 初期値
-		m_endDelayCondition.setSelection(false);
-		m_sessionCondition.setSelection(false);
-		m_sessionValue.setText(String.valueOf(1));
-		m_jobCondition.setSelection(false);
-		m_jobValue.setText(String.valueOf(1));
-		m_timeCondition.setSelection(false);
-		m_andCondition.setSelection(true);
-		m_notifyCondition.setSelection(false);
-		m_notifyPriority.select(0);
-		m_operationCondition.setSelection(false);
-		m_operationType.select(0);
-		m_operationValue.setText(String.valueOf(0));
-
 		if (m_waitRule != null) {
 			//終了遅延
 			m_endDelayCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule
@@ -553,8 +561,7 @@ public class EndDelayComposite extends Composite {
 
 			//時刻の値
 			if (m_waitRule.getEndDelayTimeValue() != null) {
-				SimpleDateFormat formatter = new SimpleDateFormat("HH:mm:ss");
-				m_timeValue.setText(formatter.format(new Date(m_waitRule.getEndDelayTimeValue())));
+				m_timeValue.setText(TimeTo48hConverter.dateTo48hms(new Date(m_waitRule.getEndDelayTimeValue())));
 			}
 			else{
 				m_timeValue.setText("");
@@ -583,6 +590,9 @@ public class EndDelayComposite extends Composite {
 			setSelectOperationName(m_operationType,
 					m_waitRule.getEndDelayOperationType());
 
+			//操作の終了状態
+			setSelectOperationEndStatus(m_operationStatus, m_waitRule.getEndDelayOperationEndStatus());
+
 			//操作の終了値
 			m_operationValue.setText(String.valueOf(m_waitRule.getEndDelayOperationEndValue()));
 		}
@@ -616,46 +626,9 @@ public class EndDelayComposite extends Composite {
 	 * 
 	 * @see com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo
 	 */
-	@SuppressWarnings("unchecked")
 	public ValidateResult createWaitRuleInfo() {
 		ValidateResult result = null;
 
-		//実行内容情報クラスのインスタンスを作成・取得
-		if (m_waitRule == null) {
-			m_waitRule = new JobWaitRuleInfo();
-			m_waitRule.setSuspend(YesNoConstant.TYPE_NO);
-			m_waitRule.setSkip(YesNoConstant.TYPE_NO);
-			m_waitRule.setSkipEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setCondition(ConditionTypeConstant.TYPE_AND);
-			m_waitRule.setEndCondition(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setCalendar(YesNoConstant.TYPE_NO);
-			m_waitRule.setCalendarEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setStartDelay(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelaySession(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelaySessionValue(1);
-			m_waitRule.setStartDelayTime(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelayConditionType(ConditionTypeConstant.TYPE_AND);
-			m_waitRule.setStartDelayNotify(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelayOperation(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelayOperationEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setEndDelay(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelaySession(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelaySessionValue(1);
-			m_waitRule.setEndDelayJob(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelayJobValue(1);
-			m_waitRule.setEndDelayTime(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelayConditionType(ConditionTypeConstant.TYPE_AND);
-			m_waitRule.setEndDelayNotify(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelayOperation(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelayOperationEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setSkipEndStatus(0);
-			m_waitRule.setEndStatus(0);
-			m_waitRule.setStartDelayNotifyPriority(0);
-			m_waitRule.setStartDelayOperationType(0);
-			m_waitRule.setEndDelayNotifyPriority(0);
-			m_waitRule.setEndDelayOperationType(0);
-		}
 		//終了遅延
 		m_waitRule.setEndDelay(YesNoConstant.booleanToType(m_endDelayCondition
 				.getSelection()));
@@ -709,7 +682,7 @@ public class EndDelayComposite extends Composite {
 			Date date = null;
 			try {
 				from = formatter.parse("00:00:00");
-				to = formatter.parse("23:59:59");
+				to = formatter.parse("48:00:00");
 				date = formatter.parse(m_timeValue.getText());
 				check = true;
 			} catch (ParseException e) {
@@ -724,7 +697,7 @@ public class EndDelayComposite extends Composite {
 			if(check){
 				//範囲チェック
 				if(date.before(from) || date.after(to)){
-					String[] args = { formatter.format(from), formatter.format(to) };
+					String[] args = { formatter.format(from), TimeTo48hConverter.dateTo48hms(to) };
 					result = new ValidateResult();
 					result.setValid(false);
 					result.setID(Messages.getString("message.hinemos.1"));
@@ -766,6 +739,7 @@ public class EndDelayComposite extends Composite {
 
 		//操作の終了値
 		try {
+			m_waitRule.setEndDelayOperationEndStatus(getSelectOperationEndStatus(m_operationStatus));
 			m_waitRule.setEndDelayOperationEndValue(
 					Integer.parseInt(m_operationValue.getText()));
 		} catch (NumberFormatException e) {
@@ -786,7 +760,7 @@ public class EndDelayComposite extends Composite {
 	 * 
 	 * @param enabled true：終了遅延を使用する、false：終了遅延を使用しない
 	 */
-	public void setEndDelayEnabled(boolean enabled) {
+	private void setEndDelayEnabled(boolean enabled) {
 		if (enabled) {
 			m_endDelayConditionGroup.setEnabled(true);
 
@@ -827,19 +801,24 @@ public class EndDelayComposite extends Composite {
 			m_operationCondition.setEnabled(true);
 			if(m_operationCondition.getSelection()){
 				m_operationType.setEnabled(true);
+				m_operationStatus.setEnabled(false);
 				m_operationValue.setEnabled(false);
 
 				int type = getSelectOperationName(m_operationType);
 				if (type == OperationConstant.TYPE_STOP_AT_ONCE) {
+					m_operationStatus.setEnabled(false);
 					m_operationValue.setEnabled(false);
 				} else if(type == OperationConstant.TYPE_STOP_SUSPEND){
+					m_operationStatus.setEnabled(false);
 					m_operationValue.setEnabled(false);
 				} else if(type == OperationConstant.TYPE_STOP_SET_END_VALUE){
+					m_operationStatus.setEnabled(true);
 					m_operationValue.setEnabled(true);
 				}
 			}
 			else{
 				m_operationType.setEnabled(false);
+				m_operationStatus.setEnabled(false);
 				m_operationValue.setEnabled(false);
 			}
 		} else {
@@ -868,6 +847,7 @@ public class EndDelayComposite extends Composite {
 			//操作
 			m_operationCondition.setEnabled(false);
 			m_operationType.setEnabled(false);
+			m_operationStatus.setEnabled(false);
 			m_operationValue.setEnabled(false);
 			m_operationConditionGroup.setEnabled(false);
 		}
@@ -881,7 +861,7 @@ public class EndDelayComposite extends Composite {
 	 * 
 	 * @see com.clustercontrol.bean.PriorityConstant
 	 */
-	public void setSelectPriority(Combo combo, int priority) {
+	private void setSelectPriority(Combo combo, int priority) {
 		String select = "";
 
 		if (priority == PriorityConstant.TYPE_CRITICAL) {
@@ -913,7 +893,7 @@ public class EndDelayComposite extends Composite {
 	 * 
 	 * @see com.clustercontrol.bean.PriorityConstant
 	 */
-	public int getSelectPriority(Combo combo) {
+	private int getSelectPriority(Combo combo) {
 		String select = combo.getText();
 
 		if (select.equals(PriorityConstant.STRING_CRITICAL)) {
@@ -939,7 +919,7 @@ public class EndDelayComposite extends Composite {
 	 * 
 	 * @see com.clustercontrol.jobmanagement.bean.OperationConstant
 	 */
-	public void setSelectOperationName(Combo combo, int operation) {
+	private void setSelectOperationName(Combo combo, int operation) {
 		String select = "";
 
 		if (operation == OperationConstant.TYPE_STOP_AT_ONCE) {
@@ -967,7 +947,7 @@ public class EndDelayComposite extends Composite {
 	 * 
 	 * @see com.clustercontrol.jobmanagement.bean.OperationConstant
 	 */
-	public int getSelectOperationName(Combo combo) {
+	private int getSelectOperationName(Combo combo) {
 		String select = combo.getText();
 
 		if (select.equals(OperationConstant.STRING_STOP_AT_ONCE)) {
@@ -980,4 +960,54 @@ public class EndDelayComposite extends Composite {
 
 		return -1;
 	}
+
+	/**
+	 * 指定した重要度に該当する終了遅延終了状態用コンボボックスの項目を選択します。
+	 * 
+	 */
+	private void setSelectOperationEndStatus(Combo combo, int status) {
+		String select = "";
+
+		select = EndStatusConstant.typeToString(status);
+
+		combo.select(0);
+		for (int i = 0; i < combo.getItemCount(); i++) {
+			if (select.equals(combo.getItem(i))) {
+				combo.select(i);
+				break;
+			}
+		}
+	}
+
+	/**
+	 * 終了遅延通知終了状態用コンボボックスにて選択している項目を取得します。
+	 * 
+	 */
+	private int getSelectOperationEndStatus(Combo combo) {
+		String select = combo.getText();
+		return EndStatusConstant.stringToType(select);
+	}
+	
+	/**
+	 * 読み込み専用時にグレーアウトします。
+	 */
+	@Override
+	public void setEnabled(boolean enabled) {
+		super.setEnabled(enabled);
+		m_sessionCondition.setEnabled(enabled);
+		m_sessionValue.setEnabled(enabled);
+		m_jobCondition.setEnabled(enabled);
+		m_jobValue.setEnabled(enabled);
+		m_timeCondition.setEnabled(enabled);
+		m_timeValue.setEnabled(enabled);
+		m_andCondition.setEnabled(enabled);
+		m_orCondition.setEnabled(enabled);
+		m_notifyCondition.setEnabled(enabled);
+		m_notifyPriority.setEnabled(enabled);
+		m_operationCondition.setEnabled(enabled);
+		m_operationType.setEnabled(enabled);
+		m_operationStatus.setEnabled(enabled);
+		m_operationValue.setEnabled(enabled);
+		m_endDelayCondition.setEnabled(enabled);
+	}
 }
\ No newline at end of file
