@@ -25,9 +25,7 @@ import org.eclipse.ui.PlatformUI;
 import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.jobmanagement.composite.JobListComposite;
 import com.clustercontrol.jobmanagement.composite.JobTreeComposite;
-import com.clustercontrol.jobmanagement.util.JobUtil;
 import com.clustercontrol.jobmanagement.view.JobListView;
-import com.clustercontrol.util.LoginManager;
 import com.clustercontrol.ws.jobmanagement.JobTreeItem;
 
 /**
@@ -38,9 +36,9 @@ import com.clustercontrol.ws.jobmanagement.JobTreeItem;
  */
 public class JobTreeSelectionChangedListener implements ISelectionChangedListener {
 	/** ジョブ[一覧]ビューのツリービューア用のコンポジット */
-	protected JobTreeComposite m_tree;
+	private JobTreeComposite m_tree;
 	/** ジョブ[一覧]ビューのテーブルビューア用のコンポジット */
-	protected JobListComposite m_list;
+	private JobListComposite m_list;
 
 	/**
 	 * コンストラクタ
@@ -78,7 +76,7 @@ public class JobTreeSelectionChangedListener implements ISelectionChangedListene
 
 		//ジョブ[登録]ビューのインスタンスを取得
 		IWorkbenchPage page = PlatformUI.getWorkbench()
-		.getActiveWorkbenchWindow().getActivePage();
+				.getActiveWorkbenchWindow().getActivePage();
 		IViewPart viewPart = page.findView(JobListView.ID);
 
 		//選択アイテムを取得
@@ -94,18 +92,12 @@ public class JobTreeSelectionChangedListener implements ISelectionChangedListene
 
 				// ログインユーザで参照可能なジョブユニットかどうかチェックする
 				if (selectItem.getData().getType() == JobConstant.TYPE_JOBUNIT) {
-
-					// 参照できない場合、各種ボタン操作を無効化する
-					if (JobUtil.isReferableJobunit(selectItem, LoginManager.getContextManager().getUserId())) {
-						view.setEnabledActionAll(true);
-						view.setEnabledAction(selectItem.getData().getType(), selection);
-					} else {
-						view.setEnabledActionAll(false);
-					}
-
+					//ビューのアクションの有効/無効を設定
+					view.setEnabledActionAll(true);
+					view.setEnabledAction(selectItem.getData().getType(), selectItem.getData().getJobunitId(), selection);
 				} else {
 					//ビューのアクションの有効/無効を設定
-					view.setEnabledAction(selectItem.getData().getType(), selection);
+					view.setEnabledAction(selectItem.getData().getType(), selectItem.getData().getJobunitId(), selection);
 				}
 
 			} else {
