@@ -28,13 +28,13 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.composite.PropertySheet;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.jobmanagement.bean.JobOperationConstant;
 import com.clustercontrol.jobmanagement.bean.OperationConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.PropertySheet;
 
 /**
  * ジョブ[開始]及びジョブ[停止]のダイアログクラスです。
@@ -44,11 +44,11 @@ import com.clustercontrol.util.PropertyUtil;
  */
 public class JobOperationDialog extends CommonDialog {
 	/** プロパティ */
-	protected Property m_property = null;
+	private Property m_property = null;
 	/** プロパティシート */
-	protected PropertySheet m_propertySheet = null;
+	private PropertySheet m_propertySheet = null;
 	/** ダイアログのタイトル */
-	protected String m_title = "";
+	private String m_title = "";
 
 	/**
 	 * コンストラクタ
@@ -196,10 +196,18 @@ public class JobOperationDialog extends CommonDialog {
 		if(values.size() > 0 && values.get(0) instanceof Integer)
 			endValue = (Integer)values.get(0);
 
-		//制御が停止[終了値の変更]または停止[スキップ]の場合、終了値をチェック
-		if(control.intValue() == OperationConstant.TYPE_STOP_MAINTENANCE ||
-				control.intValue() == OperationConstant.TYPE_STOP_SKIP ||
-				control.intValue() == OperationConstant.TYPE_STOP_FORCE){
+		if(control == -1) {
+			result = new ValidateResult();
+			result.setID(Messages.getString("message.hinemos.1"));
+			result.setMessage(Messages.getString("message.job.115"));
+			result.setValid(false);
+			return result;
+		}
+
+		//制御が停止[状態変更]または停止[スキップ]の場合、終了値をチェック
+		if(control == OperationConstant.TYPE_STOP_MAINTENANCE ||
+				control == OperationConstant.TYPE_STOP_SKIP ||
+				control == OperationConstant.TYPE_STOP_FORCE){
 			if(endValue == null){
 				result = new ValidateResult();
 				result.setID(Messages.getString("message.hinemos.1"));
