@@ -45,7 +45,7 @@ import com.clustercontrol.view.AutoUpdateView;
 public class JobManagementPreferencePage extends FieldEditorPreferencePage
 implements IWorkbenchPreferencePage {
 
-	private static Log m_log = LogFactory.getLog(JobManagementPreferencePage.class); 
+	private static Log m_log = LogFactory.getLog(JobManagementPreferencePage.class);
 
 	/** ジョブ[履歴]ビューの自動更新フラグ */
 	public static final String P_HISTORY_UPDATE_FLG = "historyUpdateFlg";
@@ -59,6 +59,9 @@ implements IWorkbenchPreferencePage {
 	/** ジョブ[履歴]ビューの表示履歴数 */
 	public static final String P_HISTORY_MAX_HISTORIES = "historyMaxHistories";
 
+	/** ジョブ[スケジュール予定]ビューの表示数*/
+	public static final String P_PLAN_MAX_SCHEDULE = "planMaxSchedule";
+
 	/**
 	 * 初期値が設定されたインスタンスを返します。
 	 * 
@@ -86,6 +89,8 @@ implements IWorkbenchPreferencePage {
 		store.setDefault(P_HISTORY_UPDATE_CYCLE, 10);
 		store.setDefault(P_HISTORY_MESSAGE_FLG, true);
 		store.setDefault(P_HISTORY_MAX_HISTORIES, 500);
+
+		store.setDefault(P_PLAN_MAX_SCHEDULE, 100);
 	}
 
 	/**
@@ -114,9 +119,9 @@ implements IWorkbenchPreferencePage {
 
 		// 周期
 		IntegerFieldEditor cycle =
-			new IntegerFieldEditor(
-					P_HISTORY_UPDATE_CYCLE,
-					Messages.getString("autoupdate.cycle") + " : ", group);
+				new IntegerFieldEditor(
+						P_HISTORY_UPDATE_CYCLE,
+						Messages.getString("autoupdate.cycle") + " : ", group);
 		cycle.setValidRange(1, DataRangeConstant.SMALLINT_HIGH);
 		String[] args = {
 				Integer.toString(1),
@@ -130,12 +135,37 @@ implements IWorkbenchPreferencePage {
 
 		// 表示履歴数
 		IntegerFieldEditor histories =
-			new IntegerFieldEditor(
-					P_HISTORY_MAX_HISTORIES,
-					Messages.getString("number.of.display.histories") + " : ", group);
+				new IntegerFieldEditor(
+						P_HISTORY_MAX_HISTORIES,
+						Messages.getString("number.of.display.histories") + " : ", group);
 		histories.setValidRange(1, DataRangeConstant.SMALLINT_HIGH);
 		histories.setErrorMessage(Messages.getString("message.hinemos.8", args ));
 		this.addField(histories);
+
+		// ジョブ[スケジュール予定]ビュー関連
+		Group planGroup = new Group(parent, SWT.SHADOW_NONE);
+
+		gridData = new GridData();
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		gridData.horizontalSpan = 10;
+		gridData.verticalSpan = 10;
+
+		planGroup.setLayoutData(gridData);
+		planGroup.setText(Messages.getString("view.job.plan"));
+
+		String[] argsPlan = {
+				Integer.toString(1),
+				Integer.toString(DataRangeConstant.SMALLINT_HIGH) };
+
+		// 表示件数
+		IntegerFieldEditor plan =
+				new IntegerFieldEditor(
+						P_PLAN_MAX_SCHEDULE,
+						Messages.getString("number.of.display.plans") + " :            ", planGroup);// FIXME レイアウトを整えるための空白
+		plan.setValidRange(1, DataRangeConstant.SMALLINT_HIGH);
+		plan.setErrorMessage(Messages.getString("message.hinemos.8", argsPlan ));
+		this.addField(plan);
 	}
 
 	/**
@@ -155,13 +185,13 @@ implements IWorkbenchPreferencePage {
 	/**
 	 * 設定内容をジョブ[履歴]ビューに反映します。
 	 */
-	protected void applySetting() {
+	private void applySetting() {
 		IPreferenceStore store = this.getPreferenceStore();
 
 		// 存在するビュー全てに設定を適応する。
 
 		IWorkbench workbench = ClusterControlPlugin.getDefault()
-		.getWorkbench();
+				.getWorkbench();
 		IWorkbenchWindow[] windows = workbench.getWorkbenchWindows();
 
 		int windowCount = windows.length;
@@ -173,6 +203,7 @@ implements IWorkbenchPreferencePage {
 			for (int j = 0; j < pageCount; j++) {
 				int cycle = store.getInt(P_HISTORY_UPDATE_CYCLE);
 				boolean flag = store.getBoolean(P_HISTORY_UPDATE_FLG);
+
 				// 本体のジョブ[履歴]ビュー
 				setUpdateSetting(
 						(AutoUpdateView) pages[j].findView(JobHistoryView.ID),
@@ -188,7 +219,7 @@ implements IWorkbenchPreferencePage {
 			}
 		}
 	}
-	
+
 	private void setUpdateSetting(AutoUpdateView view, int cycle, boolean flag) {
 		if (view != null) {
 			m_log.info("setUpdateSetting " + view.getTitle() + ", cycle=" + cycle + ", flag=" + flag);
