@@ -13,18 +13,19 @@ import com.clustercontrol.jobmanagement.bean.HistoryFilterPropertyConstant;
 import com.clustercontrol.jobmanagement.bean.JobOperationConstant;
 import com.clustercontrol.jobmanagement.bean.JobTriggerTypeConstant;
 import com.clustercontrol.jobmanagement.bean.OperationConstant;
+import com.clustercontrol.jobmanagement.bean.PlanFilterPropertyConstant;
 import com.clustercontrol.util.PropertyUtil;
 import com.clustercontrol.ws.jobmanagement.HinemosUnknown_Exception;
 import com.clustercontrol.ws.jobmanagement.InvalidRole_Exception;
 import com.clustercontrol.ws.jobmanagement.JobEndStatusInfo;
 import com.clustercontrol.ws.jobmanagement.JobHistoryFilter;
 import com.clustercontrol.ws.jobmanagement.JobInfo;
-import com.clustercontrol.ws.jobmanagement.JobManagementUserInfo;
 import com.clustercontrol.ws.jobmanagement.JobMasterNotFound_Exception;
 import com.clustercontrol.ws.jobmanagement.JobNotificationsInfo;
+import com.clustercontrol.ws.jobmanagement.JobOperationInfo;
 import com.clustercontrol.ws.jobmanagement.JobParameterInfo;
+import com.clustercontrol.ws.jobmanagement.JobPlanFilter;
 import com.clustercontrol.ws.jobmanagement.JobTreeItem;
-import com.clustercontrol.ws.jobmanagement.NodeOperationInfo;
 import com.clustercontrol.ws.jobmanagement.NotifyNotFound_Exception;
 import com.clustercontrol.ws.jobmanagement.UserNotFound_Exception;
 
@@ -32,8 +33,8 @@ public class JobPropertyUtil {
 	// ログ
 	private static Log m_log = LogFactory.getLog( JobPropertyUtil.class );
 
-	public static NodeOperationInfo property2nodeOperation (Property property) {
-		NodeOperationInfo info = new NodeOperationInfo();
+	public static JobOperationInfo property2jobOperation (Property property) {
+		JobOperationInfo info = new JobOperationInfo();
 
 		//セッションID取得
 		ArrayList values = PropertyUtil.getPropertyValue(property, JobOperationConstant.SESSION);
@@ -64,6 +65,11 @@ public class JobPropertyUtil {
 			info.setControl(control);
 		}
 
+		//終了状態取得
+		values = PropertyUtil.getPropertyValue(property, JobOperationConstant.END_STATUS);
+		if(values.size() > 0 && values.get(0) instanceof Integer)
+			info.setEndStatus((Integer)values.get(0));
+
 		//終了値取得
 		values = PropertyUtil.getPropertyValue(property, JobOperationConstant.END_VALUE);
 		if(values.size() > 0 && values.get(0) instanceof Integer)
@@ -131,6 +137,40 @@ public class JobPropertyUtil {
 			triggerInfo = (String) values.get(0);
 			filter.setTriggerInfo(triggerInfo);
 		}
+		
+		//オーナーロールID
+		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.OWNER_ROLE_ID);
+		String ownerRoleId = null;
+		if(!"".equals(values.get(0))) {
+			ownerRoleId = (String) values.get(0);
+			filter.setOwnerRoleId(ownerRoleId);
+		}
+		return filter;
+	}
+	public static JobPlanFilter property2jobPlanFilter (Property property) {
+		JobPlanFilter filter = new JobPlanFilter();
+		ArrayList values = null;
+
+		//開始取得
+		values = PropertyUtil.getPropertyValue(property, PlanFilterPropertyConstant.FROM_DATE);
+		m_log.trace("JobPlanFilter fromDate :");
+		if(values.get(0) != null && values.get(0) instanceof Date){
+			m_log.trace(" " + ((Date)values.get(0)).getTime());
+			filter.setFromDate(((Date)values.get(0)).getTime());
+		}
+		//終了取得
+		values = PropertyUtil.getPropertyValue(property, PlanFilterPropertyConstant.TO_DATE);
+		m_log.trace("JobPlanFilter toDate :");
+		if(values.get(0) != null && values.get(0) instanceof Date){
+			m_log.trace(" " + ((Date)values.get(0)).getTime());
+			filter.setToDate(((Date)values.get(0)).getTime());
+		}
+		//実行契機ID
+		values = PropertyUtil.getPropertyValue(property, PlanFilterPropertyConstant.SCHEDULE_ID);
+		if(values.get(0) != null){
+			m_log.trace(" " + ((String)values.get(0)));
+			filter.setJobKickId((String)values.get(0));
+		}
 		return filter;
 	}
 
@@ -187,9 +227,11 @@ public class JobPropertyUtil {
 		}
 
 		jobInfo.setCommand(ret.getCommand());
+		//		jobInfo.seto
 		jobInfo.setCreateTime(ret.getCreateTime());
 		jobInfo.setCreateUser(ret.getCreateUser());
 		jobInfo.setDescription(ret.getDescription());
+		jobInfo.setOwnerRoleId(ret.getOwnerRoleId());
 		List<JobEndStatusInfo> jobEndStatusInfoList = jobInfo.getEndStatus();
 		jobEndStatusInfoList.clear();
 		if (ret.getEndStatus() != null) {
@@ -198,11 +240,6 @@ public class JobPropertyUtil {
 		jobInfo.setFile(ret.getFile());
 		// jobInfo.setId(ret.getId());
 		// jobInfo.setJobunitId(ret.getJobunitId());
-		List<JobManagementUserInfo> jobManagementUserInfoList = jobInfo.getManagementUser();
-		jobManagementUserInfoList.clear();
-		if (ret.getManagementUser() != null) {
-			jobManagementUserInfoList.addAll(ret.getManagementUser());
-		}
 		// jobInfo.setName(ret.getName());
 		List<JobNotificationsInfo> jobNotificationsInfoList = jobInfo.getNotifications();
 		jobNotificationsInfoList.clear();
@@ -219,5 +256,13 @@ public class JobPropertyUtil {
 		jobInfo.setUpdateTime(ret.getUpdateTime());
 		jobInfo.setUpdateUser(ret.getUpdateUser());
 		jobInfo.setWaitRule(ret.getWaitRule());
+
+		//参照ジョブ
+		if(ret.getReferJobUnitId() != null){
+			jobInfo.setReferJobUnitId(ret.getReferJobUnitId());
+		}
+		if(ret.getReferJobId() != null){
+			jobInfo.setReferJobId(ret.getReferJobId());
+		}
 	}
 }
