@@ -31,8 +31,9 @@ import org.eclipse.ui.IViewPart;
 import org.eclipse.ui.PlatformUI;
 
 import com.clustercontrol.bean.DataRangeConstant;
+import com.clustercontrol.bean.EndStatusConstant;
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.bean.PropertyConstant;
+import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.jobmanagement.action.OperationJob;
 import com.clustercontrol.jobmanagement.bean.JobOperationConstant;
 import com.clustercontrol.jobmanagement.bean.OperationConstant;
@@ -61,7 +62,7 @@ public class StopJobAction implements IViewActionDelegate {
 	/** アクションID */
 	public static final String ID = "com.clustercontrol.jobmanagement.view.action.StopJobAction";
 	/** ビュー */
-	protected IViewPart m_view;
+	private IViewPart m_view;
 
 	/**
 	 * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
@@ -103,7 +104,7 @@ public class StopJobAction implements IViewActionDelegate {
 
 		if (m_view instanceof JobHistoryView) { // ボタンが押された場合
 			JobHistoryView view = (JobHistoryView) m_view
-			.getAdapter(JobHistoryView.class);
+					.getAdapter(JobHistoryView.class);
 			HistoryComposite historyComposite = view.getComposite();
 			//セッションID取得
 			sessionId = historyComposite.getSessionId();
@@ -113,7 +114,7 @@ public class StopJobAction implements IViewActionDelegate {
 			jobId = historyComposite.getJobId();
 		} else if (m_view instanceof JobDetailView) { // ボタンが押された場合
 			JobDetailView view = (JobDetailView) m_view
-			.getAdapter(JobDetailView.class);
+					.getAdapter(JobDetailView.class);
 			DetailComposite detailComposite = view.getComposite();
 			//セッションID取得
 			sessionId = detailComposite.getSessionId();
@@ -123,7 +124,7 @@ public class StopJobAction implements IViewActionDelegate {
 			jobId = detailComposite.getJobId();
 		} else if (m_view instanceof JobNodeDetailView) { // ボタンが押された場合
 			JobNodeDetailView view = (JobNodeDetailView) m_view
-			.getAdapter(JobNodeDetailView.class);
+					.getAdapter(JobNodeDetailView.class);
 			NodeDetailComposite nodeDetailComposite = view.getComposite();
 			//セッションID取得
 			sessionId = nodeDetailComposite.getSessionId();
@@ -185,39 +186,61 @@ public class StopJobAction implements IViewActionDelegate {
 
 		//セッションID
 		Property session =
-			new Property(JobOperationConstant.SESSION, Messages.getString("session.id", locale), PropertyConstant.EDITOR_TEXT);
+				new Property(JobOperationConstant.SESSION, Messages.getString("session.id", locale), PropertyDefineConstant.EDITOR_TEXT);
+		session.setValue(sessionId);
+
 		//ジョブユニットID
 		Property jobUnit =
-			new Property(JobOperationConstant.JOB_UNIT, Messages.getString("jobunit.id", locale), PropertyConstant.EDITOR_TEXT);
+				new Property(JobOperationConstant.JOB_UNIT, Messages.getString("jobunit.id", locale), PropertyDefineConstant.EDITOR_TEXT);
+		jobUnit.setValue(jobunitId);
+
 		//ジョブID
 		Property job =
-			new Property(JobOperationConstant.JOB, Messages.getString("job.id", locale), PropertyConstant.EDITOR_TEXT);
+				new Property(JobOperationConstant.JOB, Messages.getString("job.id", locale), PropertyDefineConstant.EDITOR_TEXT);
+		job.setValue(jobId);
+
 		//ファシリティID
 		Property facility =
-			new Property(JobOperationConstant.FACILITY, Messages.getString("facility.id", locale), PropertyConstant.EDITOR_TEXT);
-		//制御
-		Property control =
-			new Property(JobOperationConstant.CONTROL, Messages.getString("control", locale), PropertyConstant.EDITOR_SELECT);
+				new Property(JobOperationConstant.FACILITY, Messages.getString("facility.id", locale), PropertyDefineConstant.EDITOR_TEXT);
+		ArrayList<Property> endList = new ArrayList<Property>();
+		if(facilityId != null && facilityId.length() > 0){
+			facility.setValue(facilityId);
+		}else{
+			facility.setValue("");
+		}
+
+		//終了状態
+		Property endStatus = null;
+		if (facilityId == null) {
+			endStatus = new Property(JobOperationConstant.END_STATUS, Messages.getString("end.status", locale), PropertyDefineConstant.EDITOR_SELECT);
+			Object endStatusList[][] = {
+					{"", EndStatusConstant.STRING_NORMAL, EndStatusConstant.STRING_WARNING, EndStatusConstant.STRING_ABNORMAL},
+					{"", EndStatusConstant.TYPE_NORMAL, EndStatusConstant.TYPE_WARNING, EndStatusConstant.TYPE_ABNORMAL}
+			};
+			endStatus.setSelectValues(endStatusList);
+			endStatus.setValue("");
+			endList.add(endStatus);
+		}
+
 		//終了値
 		Property endValue =
-			new Property(JobOperationConstant.END_VALUE, Messages.getString("end.value", locale), PropertyConstant.EDITOR_NUM,
-					DataRangeConstant.SMALLINT_HIGH, DataRangeConstant.SMALLINT_LOW);
-
-		ArrayList<Property> endList = new ArrayList<Property>();
+				new Property(JobOperationConstant.END_VALUE, Messages.getString("end.value", locale), PropertyDefineConstant.EDITOR_NUM,
+						DataRangeConstant.SMALLINT_HIGH, DataRangeConstant.SMALLINT_LOW);
+		endValue.setValue("");
 		endList.add(endValue);
 
+		//制御
+		Property control =
+				new Property(JobOperationConstant.CONTROL, Messages.getString("control", locale), PropertyDefineConstant.EDITOR_SELECT);
 		HashMap<String, Object> skipEndMap = new HashMap<String, Object>();
 		skipEndMap.put("value", OperationConstant.STRING_STOP_SKIP);
 		skipEndMap.put("property", endList);
-
 		HashMap<String, Object> mainteEndMap = new HashMap<String, Object>();
 		mainteEndMap.put("value", OperationConstant.STRING_STOP_MAINTENANCE);
 		mainteEndMap.put("property", endList);
-
 		HashMap<String, Object> forceEndMap = new HashMap<String, Object>();
 		forceEndMap.put("value", OperationConstant.STRING_STOP_FORCE);
 		forceEndMap.put("property", endList);
-
 		List<String> values1 = null;
 		try {
 			values1 = JobEndpointWrapper.getAvailableStopOperation(sessionId, jobunitId, jobId, facilityId);
@@ -231,7 +254,6 @@ public class StopJobAction implements IViewActionDelegate {
 					Messages.getString("failed"),
 					Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
 		}
-
 		ArrayList<Object> values2 = new ArrayList<Object>();
 		if(values1.contains(OperationConstant.STRING_STOP_AT_ONCE)) {
 			values2.add(OperationConstant.STRING_STOP_AT_ONCE);
@@ -251,54 +273,43 @@ public class StopJobAction implements IViewActionDelegate {
 		if(values1.contains(OperationConstant.STRING_STOP_FORCE)) {
 			values2.add(forceEndMap);
 		}
-
-
-		//値を初期化
 		Object controlValues[][] = {values1.toArray(), values2.toArray()};
-
 		control.setSelectValues(controlValues);
 		if(values1.size() >= 1){
 			control.setValue(values1.get(0));
-		}
-		else{
+		}else{
 			control.setValue("");
 		}
 
-		endValue.setValue("");
-
-		session.setValue(sessionId);
-		jobUnit.setValue(jobunitId);
-		job.setValue(jobId);
-		if(facilityId != null && facilityId.length() > 0){
-			facility.setValue(facilityId);
-		}
-		else{
-			facility.setValue("");
-		}
-
 		//変更の可/不可を設定
-		session.setModify(PropertyConstant.MODIFY_NG);
-		jobUnit.setModify(PropertyConstant.MODIFY_NG);
-		job.setModify(PropertyConstant.MODIFY_NG);
-		facility.setModify(PropertyConstant.MODIFY_NG);
-		control.setModify(PropertyConstant.MODIFY_OK);
-		endValue.setModify(PropertyConstant.MODIFY_OK);
-
-		Property property = new Property(null, null, "");
+		session.setModify(PropertyDefineConstant.MODIFY_NG);
+		jobUnit.setModify(PropertyDefineConstant.MODIFY_NG);
+		job.setModify(PropertyDefineConstant.MODIFY_NG);
+		facility.setModify(PropertyDefineConstant.MODIFY_NG);
+		control.setModify(PropertyDefineConstant.MODIFY_OK);
+		if (endStatus != null) {
+			endStatus.setModify(PropertyDefineConstant.MODIFY_OK);
+		}
+		endValue.setModify(PropertyDefineConstant.MODIFY_OK);
 
 		// 初期表示ツリーを構成。
+		Property property = new Property(null, null, "");
 		property.removeChildren();
 		property.addChildren(session);
 		property.addChildren(jobUnit);
 		property.addChildren(job);
-		if(facilityId != null && facilityId.length() > 0){
+		if(facilityId != null){
 			property.addChildren(facility);
 		}
 		property.addChildren(control);
 
-		if(OperationConstant.STRING_STOP_SKIP.compareTo((String)control.getValue()) == 0 ||
-				OperationConstant.STRING_STOP_MAINTENANCE.compareTo((String)control.getValue()) == 0 ||
-				OperationConstant.STRING_STOP_FORCE.compareTo((String)control.getValue()) == 0 ){
+		String controlStr = (String)control.getValue();
+		if(OperationConstant.STRING_STOP_SKIP.equals(controlStr) ||
+				OperationConstant.STRING_STOP_MAINTENANCE.equals(controlStr) ||
+				OperationConstant.STRING_STOP_FORCE.equals(controlStr)){
+			if (endStatus != null) {
+				control.addChildren(endStatus);
+			}
 			control.addChildren(endValue);
 		}
 
