@@ -59,17 +59,20 @@ public class GetMaintenanceListTableDefine {
 	 */
 	public static final int VALID_FLG = 6;
 
+	/** オーナーロール */
+	public static final int OWNER_ROLE = 7;
+
 	/** 新規作成ユーザ。 */
-	public static final int CREATE_USER = 7;
+	public static final int CREATE_USER = 8;
 
 	/** 作成日時。 */
-	public static final int CREATE_TIME = 8;
+	public static final int CREATE_TIME = 9;
 
 	/** 最終変更ユーザ。 */
-	public static final int UPDATE_USER = 9;
+	public static final int UPDATE_USER = 10;
 
 	/** 最終変更日時。 */
-	public static final int UPDATE_TIME = 10;
+	public static final int UPDATE_TIME = 11;
 
 	/** 初期表示時ソートカラム。 */
 	public static final int SORT_COLUMN_INDEX = MAINTENANCE_ID;
@@ -109,6 +112,10 @@ public class GetMaintenanceListTableDefine {
 		tableDefine.add(VALID_FLG,
 				new TableColumnInfo(Messages.getString("valid", locale) + "/" + Messages.getString("invalid", locale), TableColumnInfo.VALID, 80, SWT.LEFT));
 
+		// オーナーロール
+		tableDefine.add(OWNER_ROLE,
+				new TableColumnInfo(Messages.getString("owner.role.id", locale), TableColumnInfo.NONE, 130, SWT.LEFT));
+
 		tableDefine.add(CREATE_USER,
 				new TableColumnInfo(Messages.getString("creator.name", locale), TableColumnInfo.NONE, 80, SWT.LEFT));
 
