@@ -34,7 +34,6 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Table;
 
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.monitor.run.action.GetMonitorListTableDefine;
 import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
 import com.clustercontrol.monitor.util.MonitorFilterPropertyUtil;
@@ -42,6 +41,7 @@ import com.clustercontrol.monitor.util.MonitorSettingEndpointWrapper;
 import com.clustercontrol.monitor.view.action.MonitorModifyAction;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.monitor.HinemosUnknown_Exception;
 import com.clustercontrol.ws.monitor.InvalidRole_Exception;
 import com.clustercontrol.ws.monitor.MonitorFilterInfo;
@@ -242,26 +242,27 @@ public class MonitorListComposite extends Composite {
 
 		// MonitorInfo を tableViewer にセットするための詰め替え
 		ArrayList<Object> listInput = new ArrayList<Object>();
-		for (MonitorInfo monotor : list) {
+		for (MonitorInfo monitor : list) {
 			ArrayList<Object> a = new ArrayList<Object>();
 
-			a.add(monotor.getMonitorId());
-			a.add(monotor.getMonitorTypeId());
-			a.add(MonitorTypeConstant.typeToString(monotor.getMonitorType()));
-			a.add(monotor.getDescription());
-			a.add(monotor.getScope());
-			a.add(monotor.getCalendarId());
-			if(monotor.getRunInterval() == 0){
+			a.add(monitor.getMonitorId());
+			a.add(monitor.getMonitorTypeId());
+			a.add(MonitorTypeConstant.typeToString(monitor.getMonitorType()));
+			a.add(monitor.getDescription());
+			a.add(monitor.getScope());
+			a.add(monitor.getCalendarId());
+			if(monitor.getRunInterval() == 0){
 				a.add("-");
 			}else{
-				a.add(monotor.getRunInterval() / 60 + Messages.getString("minute"));
+				a.add(monitor.getRunInterval() / 60 + Messages.getString("minute"));
 			}
-			a.add(monotor.getMonitorFlg());
-			a.add(monotor.getCollectorFlg());
-			a.add(monotor.getRegUser());
-			a.add(new Date(monotor.getRegDate()));
-			a.add(monotor.getUpdateUser());
-			a.add(new Date(monotor.getUpdateDate()));
+			a.add(monitor.getMonitorFlg());
+			a.add(monitor.getCollectorFlg());
+			a.add(monitor.getOwnerRoleId());
+			a.add(monitor.getRegUser());
+			a.add(new Date(monitor.getRegDate()));
+			a.add(monitor.getUpdateUser());
+			a.add(new Date(monitor.getUpdateDate()));
 
 			listInput.add(a);
 		}
@@ -289,6 +290,15 @@ public class MonitorListComposite extends Composite {
 		return this.tableViewer;
 	}
 
+	/**
+	 * このコンポジットが利用するテーブルを返します。
+	 * 
+	 * @return テーブル
+	 */
+	public Table getTable() {
+		return this.tableViewer.getTable();
+	}
+
 	/**
 	 * コンポジットを更新します。
 	 * <p>
