@@ -15,18 +15,18 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.notify.util;
 
+import java.io.File;
+import java.io.FileInputStream;
 import java.io.UnsupportedEncodingException;
-import java.rmi.RemoteException;
 import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.Locale;
 import java.util.Map;
+import java.util.Properties;
 import java.util.StringTokenizer;
 import java.util.Vector;
 
-import javax.ejb.CreateException;
-import javax.ejb.FinderException;
 import javax.mail.AuthenticationFailedException;
 import javax.mail.Message;
 import javax.mail.MessagingException;
@@ -36,23 +36,16 @@ import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
 import javax.mail.internet.MimeMessage;
 import javax.mail.internet.MimeUtility;
-import javax.naming.Context;
-import javax.naming.InitialContext;
-import javax.naming.NamingException;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.PriorityConstant;
-import com.clustercontrol.commons.util.HinemosProperties;
 import com.clustercontrol.notify.bean.NotifyRequestMessage;
 import com.clustercontrol.notify.bean.OutputBasicInfo;
-import com.clustercontrol.notify.ejb.entity.NotifyMailInfoData;
-import com.clustercontrol.notify.ejb.entity.NotifyMailInfoLocal;
-import com.clustercontrol.notify.ejb.entity.NotifyMailInfoPK;
-import com.clustercontrol.notify.ejb.entity.NotifyMailInfoUtil;
 import com.clustercontrol.notify.mail.bean.MailTemplateInfo;
-import com.clustercontrol.notify.mail.ejb.session.MailTemplateControllerUtil;
+import com.clustercontrol.notify.mail.session.MailTemplateControllerBean;
+import com.clustercontrol.notify.model.NotifyMailInfoEntity;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.StringBinder;
 import com.clustercontrol.util.apllog.AplLogger;
@@ -68,99 +61,102 @@ public class SendMail implements Notifier {
 	/** ログ出力のインスタンス。 */
 	private static Log m_log = LogFactory.getLog(SendMail.class);
 
+	public static final String _configFilePath;
+	public static final String _configFilePathDefault = System.getProperty("hinemos.manager.etc.dir") + File.separator + "mail-service.properties";
+
+	public static final Properties _properties = new Properties();
+
 	/** 日時フォーマット。 */
-	private static final String SUBJECT_DATE_FORMAT = "yyyy/MM/dd HH:mm:ss";
+	private static final String SUBJECT_DATE_FORMAT = "yyyy-MM-dd HH:mm:ss";
+
+	/** 接続ユーザ名 */
+	private static final String _loginUser;
+	/** 接続パスワード */
+	private static final String _loginPassword;
 
 	/** 差出人アドレス。 */
-	static private String FROM_ADDRESS = null;
+	private static final String _fromAddress;
 	/** 差出人個人名。 */
-	static private String FROM_PERSONAL_NAME = null;
+	private static final String _fromPersonalName;
 	/** 返信の送信先アドレス。 */
-	static private String REPLY_TO_ADDRESS = null;
+	private static final String _replyToAddress;
 	/** 返信の送信先個人名。 */
-	static private String REPLY_TO_PERSONAL_NAME = null;
+	private static final String _replyToPersonalName;
 	/** エラー送信先アドレス。 */
-	static private String ERRORS_TO_ADDRESS = null;
+	private static final String _errorsToAddress;
 	/** 再送回数。 */
-	static private int RETRY_COUNT = 0;
+	private static final int _transportTries;
 	/** 再送スリープ */
-	static private int RETRY_SLEEP = 10000; // デフォルトは10秒。
+	private static final int _transportTriesInterval; // デフォルトは10秒。
 	/** ロケール情報。 */
-	private Locale m_local = Locale.getDefault();
+	private static final Locale m_local = Locale.getDefault();
 
 	/** アドレスロケール */
-	public static final String _CHARSET_ADDRESS;
-	public static final String _CHARSET_ADDRESS_DEFAULT = "UTF-8";
-	
+	public static final String _charsetAddress;
+	public static final String _charsetAddressDefault = "UTF-8";
+
 	/** メール件名ロケール */
-	public static final String _CHARSET_SUBJECT;
-	public static final String _CHARSET_SUBJECT_DEFAULT = "UTF-8";
-	
+	public static final String _charsetSubject;
+	public static final String _charsetSubjectDefault = "UTF-8";
+
 	/**`メール本文ロケール */
-	public static final String _CHARSET_CONTENT;
-	public static final String _CHARSET_CONTENT_DEFAULT = "UTF-8";
-	
+	public static final String _charsetContent;
+	public static final String _charsetContentDefault = "UTF-8";
+
 	static {
-		String charsetAddress = _CHARSET_ADDRESS_DEFAULT;
-		String charsetSubject = _CHARSET_SUBJECT_DEFAULT;
-		String charsetContent = _CHARSET_CONTENT_DEFAULT;
-		
+		_configFilePath = System.getProperty("hinemos.log4j.file", _configFilePathDefault);
+
+		FileInputStream fin = null;
+		try {
+			fin = new FileInputStream(_configFilePath);
+			_properties.load(fin);
+		} catch (Exception e) {
+			m_log.warn("config file loading failure. (" + _configFilePath + ")", e);
+		} finally {
+			if (fin != null) {
+				try {
+					fin.close();
+				} catch (Exception e) {
+					m_log.warn("file closing failure.", e);
+				}
+			}
+		}
+
 		/**
 		 * メールの設定をプロパティファイルから取得
 		 */
-		// FIXME RuntimeのExceptionが発生する恐れがあるためtry-catchとする
-		try {
-			FROM_ADDRESS = HinemosProperties
-			.getProperty("common.mail.from.address");
-			FROM_PERSONAL_NAME = HinemosProperties
-			.getProperty("common.mail.from.personal.name");
-			REPLY_TO_ADDRESS = HinemosProperties
-			.getProperty("common.mail.reply.to.address");
-			REPLY_TO_PERSONAL_NAME = HinemosProperties
-			.getProperty("common.mail.reply.personal.name");
-			ERRORS_TO_ADDRESS = HinemosProperties
-			.getProperty("common.mail.errors.to.address");
-			RETRY_COUNT = Integer.parseInt(HinemosProperties
-					.getProperty("common.mail.retry.count"));
-			RETRY_SLEEP = Integer.parseInt(HinemosProperties
-					.getProperty("common.mail.retry.sleep"));
-			
-			charsetAddress = HinemosProperties.getProperty("common.mail.charset.address", _CHARSET_ADDRESS_DEFAULT);
-			charsetSubject = HinemosProperties.getProperty("common.mail.charset.subject", _CHARSET_SUBJECT_DEFAULT);
-			charsetContent = HinemosProperties.getProperty("common.mail.charset.content", _CHARSET_CONTENT_DEFAULT);
-			
-		} catch (Exception e) {
-			m_log.warn(e.getMessage(), e);
-		}
-		
-		_CHARSET_ADDRESS = charsetAddress;
-		_CHARSET_SUBJECT = charsetSubject;
-		_CHARSET_CONTENT = charsetContent;
-		
-		m_log.info("initialized mail sender : from_address = " + FROM_ADDRESS 
-				+ ", From = " + FROM_PERSONAL_NAME + " <" + REPLY_TO_ADDRESS + ">"
-				+ ", Reply-To = " + REPLY_TO_PERSONAL_NAME + " <" + REPLY_TO_ADDRESS + ">"
-				+ ", Errors-To = " + ERRORS_TO_ADDRESS
-				+ ", retries = " + RETRY_COUNT
-				+ ", retry-sleep = " + RETRY_SLEEP
-				+ ", Charset [address:subject:content] = [" + _CHARSET_ADDRESS + ":" + _CHARSET_SUBJECT + ":" + _CHARSET_CONTENT + "]");
+		_loginUser = _properties.getProperty("hinemos.mail.transport.user");
+		_loginPassword = _properties.getProperty("hinemos.mail.transport.password");
+
+		_fromAddress = _properties.getProperty("hinemos.mail.from.address");
+		_fromPersonalName = _properties.getProperty("hinemos.mail.from.personal.name");
+		_replyToAddress = _properties.getProperty("hinemos.mail.reply.to.address");
+		_replyToPersonalName = _properties.getProperty("hinemos.mail.reply.personal.name");
+		_errorsToAddress = _properties.getProperty("hinemos.mail.errors.to.address");
+
+		_transportTries = Integer.parseInt(_properties.getProperty("hinemos.mail.tranport.tries", "1"));
+		_transportTriesInterval = Integer.parseInt(_properties.getProperty("hinemos.mail.tranport.tries.interval", "10000"));
+
+		_charsetAddress = _properties.getProperty("hinemos.mail.charset.address", _charsetAddressDefault);
+		_charsetSubject = _properties.getProperty("hinemos.mail.charset.subject", _charsetSubjectDefault);
+		_charsetContent = _properties.getProperty("hinemos.mail.charset.content", _charsetContentDefault);
+
+		m_log.info("initialized mail sender : from_address = " + _fromAddress
+				+ ", From = " + _fromPersonalName + " <" + _replyToAddress + ">"
+				+ ", Reply-To = " + _replyToPersonalName + " <" + _replyToAddress + ">"
+				+ ", Errors-To = " + _errorsToAddress
+				+ ", tries = " + _transportTries
+				+ ", tries-interval = " + _transportTriesInterval
+				+ ", Charset [address:subject:content] = [" + _charsetAddress + ":" + _charsetSubject + ":" + _charsetContent + "]");
 	}
 
 	/**
 	 * メールの送信を行います。
 	 * 
 	 * @param outputInfo 出力・通知情報
-	 * @throws UnsupportedEncodingException
-	 * @throws RemoteException
-	 * @throws NamingException
-	 * @throws MessagingException
-	 * @throws CreateException
-	 * @throws FinderException
 	 */
 	@Override
-	public synchronized void notify(NotifyRequestMessage message)
-	throws UnsupportedEncodingException, RemoteException,
-	NamingException, CreateException, FinderException {
+	public synchronized void notify(NotifyRequestMessage message) {
 
 		sendMail(message.getOutputInfo(), message.getNotifyId());
 	}
@@ -168,27 +164,21 @@ public class SendMail implements Notifier {
 	/**
 	 * メールの送信を行います。
 	 * 
-	 * @throws MessagingException
-	 * @throws
 	 */
 	private void sendMail(OutputBasicInfo outputInfo, String notifyId) {
+
 		if (m_log.isDebugEnabled()) {
-			m_log.debug("notify() " + outputInfo);
+			m_log.debug("sendMail() " + outputInfo);
 		}
 
 		try {
-			NotifyMailInfoLocal mailInfo = NotifyMailInfoUtil.getLocalHome()
-			.findByPrimaryKey(
-					new NotifyMailInfoPK(notifyId, outputInfo
-							.getPriority()));
-
-			NotifyMailInfoData mailInfoData = mailInfo.getData();
+			NotifyMailInfoEntity mailInfo = QueryUtil.getNotifyMailInfoPK(notifyId, outputInfo.getPriority());
 
 			// メールの件名を指定
-			String subject = getSubject(outputInfo, mailInfoData);
+			String subject = getSubject(outputInfo, mailInfo);
 
 			// メールの内容を指定
-			String content = getContent(outputInfo, mailInfoData);
+			String content = getContent(outputInfo, mailInfo);
 
 			/**
 			 * メール送信
@@ -210,20 +200,24 @@ public class SendMail implements Notifier {
 				this.sendMail(addresses, subject, content);
 			} catch (AuthenticationFailedException e) {
 				String detailMsg = "cannot connect to the mail server due to an Authentication Failure";
-				m_log.error("sendMail():" + e.getMessage() + " : " + detailMsg);
+				m_log.warn("sendMail() " + e.getMessage() + " : " + detailMsg + " : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 				internalErrorNotify(notifyId, "007", detailMsg);
 			} catch (SMTPAddressFailedException e) {
 				String detailMsg = e.getMessage() + "(SMTPAddressFailedException)";
-				m_log.error("sendMail():" + detailMsg);
+				m_log.warn("sendMail() " + e.getMessage() + " : " + detailMsg + " : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 				internalErrorNotify(notifyId, "007", detailMsg);
 			} catch (MessagingException e) {
 				String detailMsg = e.getCause() != null ? e.getMessage() + "\nCause : " + e.getCause().getMessage() : e.getMessage();
-				m_log.error("sendMail():" + e.getMessage(), e);
+				m_log.warn("sendMail() " + e.getMessage() + " : " + detailMsg + " : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 				internalErrorNotify(notifyId, "007", detailMsg);
 			}
 		} catch (Exception e1) {
 			String detailMsg = e1.getCause() != null ? e1.getMessage() + "\nCause : " + e1.getCause().getMessage() : e1.getMessage();
-			m_log.error("sendMail():" + e1.getMessage(), e1);
+			m_log.warn("sendMail() " + e1.getMessage() + " : " + detailMsg + detailMsg + " : "
+					+ e1.getClass().getSimpleName() + ", " + e1.getMessage(), e1);
 			internalErrorNotify(notifyId, "007", detailMsg);
 		}
 	}
@@ -247,51 +241,43 @@ public class SendMail implements Notifier {
 	 * @param source
 	 *            出力内容
 	 * @return 送信に成功した場合、<code> true </code>
-	 * @throws NamingException
 	 * @throws MessagingException
 	 * @throws NamingException
 	 * @throws UnsupportedEncodingException
-	 * @throws NamingException
-	 * @throws UnsupportedEncodingException
 	 */
 	public void sendMail(String[] address, String subject, String content)
-	throws MessagingException, NamingException, UnsupportedEncodingException {
+			throws MessagingException, UnsupportedEncodingException {
 
 		if (address == null || address.length <= 0) {
 			// 何もせず終了
 			return;
 		}
 
-		Context initialContext = new InitialContext();
-
-		// 再送信フラグ設定
-		boolean retryFlg = true;
-
 		// JavaMail Sessionリソース検索
-		Session session = (Session) initialContext.lookup("java:/Mail");
+		Session session = Session.getDefaultInstance(_properties);
 
-		Message mes = new MimeMessage(session);
+		Message mineMsg = new MimeMessage(session);
 
 		// 送信元メールアドレスと送信者名を指定
-		if (FROM_ADDRESS != null && FROM_PERSONAL_NAME != null) {
-			mes.setFrom(new InternetAddress(FROM_ADDRESS, FROM_PERSONAL_NAME, _CHARSET_ADDRESS));
-		} else if (FROM_ADDRESS != null && FROM_PERSONAL_NAME == null) {
-			mes.setFrom(new InternetAddress(FROM_ADDRESS));
+		if (_fromAddress != null && _fromPersonalName != null) {
+			mineMsg.setFrom(new InternetAddress(_fromAddress, _fromPersonalName, _charsetAddress));
+		} else if (_fromAddress != null && _fromPersonalName == null) {
+			mineMsg.setFrom(new InternetAddress(_fromAddress));
 		}
 		// REPLY-TOを指定
-		if (REPLY_TO_ADDRESS != null && REPLY_TO_PERSONAL_NAME != null) {
-			InternetAddress reply[] = { new InternetAddress(REPLY_TO_ADDRESS, REPLY_TO_PERSONAL_NAME, _CHARSET_ADDRESS) };
-			mes.setReplyTo(reply);
-			mes.reply(true);
-		} else if (REPLY_TO_ADDRESS != null && REPLY_TO_PERSONAL_NAME == null) {
-			InternetAddress reply[] = { new InternetAddress(REPLY_TO_ADDRESS) };
-			mes.setReplyTo(reply);
-			mes.reply(true);
+		if (_replyToAddress != null && _replyToPersonalName != null) {
+			InternetAddress reply[] = { new InternetAddress(_replyToAddress, _replyToPersonalName, _charsetAddress) };
+			mineMsg.setReplyTo(reply);
+			mineMsg.reply(true);
+		} else if (_replyToAddress != null && _replyToPersonalName == null) {
+			InternetAddress reply[] = { new InternetAddress(_replyToAddress) };
+			mineMsg.setReplyTo(reply);
+			mineMsg.reply(true);
 		}
 
 		// ERRORS-TOを指定
-		if (ERRORS_TO_ADDRESS != null) {
-			mes.setHeader("Errors-To", ERRORS_TO_ADDRESS);
+		if (_errorsToAddress != null) {
+			mineMsg.setHeader("Errors-To", _errorsToAddress);
 		}
 
 		// 送信先メールアドレスを指定
@@ -300,42 +286,41 @@ public class SendMail implements Notifier {
 			// 何もせず終了
 			return;
 		}
-		mes.setRecipients(javax.mail.Message.RecipientType.TO, toAddress);
+		mineMsg.setRecipients(javax.mail.Message.RecipientType.TO, toAddress);
 
 		// メールの件名を指定
-		mes.setSubject(MimeUtility.encodeText(subject, _CHARSET_SUBJECT, "B"));
+		mineMsg.setSubject(MimeUtility.encodeText(subject, _charsetSubject, "B"));
 
 		// メールの内容を指定
-		mes.setContent(content, "text/plain; charset=" + _CHARSET_CONTENT);
+		mineMsg.setContent(content, "text/plain; charset=" + _charsetContent);
 
 		// 送信日付を指定
-		mes.setSentDate(new Date());
+		mineMsg.setSentDate(new Date());
 
 		// 再送信フラグがtrueかつ再送回数以内の場合
-		for (int i = 0; i < RETRY_COUNT + 1 && retryFlg; i++) {
+		for (int i = 0; i < _transportTries; i++) {
+			Transport transport = null;
 			try {
 				// メール送信
-				Transport.send(mes);
-				retryFlg = false;
+				transport = session.getTransport();
+				transport.connect(_loginUser, _loginPassword);
+				transport.sendMessage(mineMsg, mineMsg.getAllRecipients());
 			} catch (AuthenticationFailedException e) {
 				throw e;
 			} catch (SMTPAddressFailedException e) {
 				throw e;
 			} catch (MessagingException me) {
-				// メール再送信フラグを挙げる
-				retryFlg = true;
-				if (i < RETRY_COUNT) {
-					m_log.warn("sendMail() : resend mail");
+				if (i < _transportTries) {
+					m_log.info("sendMail() : retry sendmail. " + me.getMessage());
+					try {
+						Thread.sleep(_transportTriesInterval);
+					} catch (InterruptedException e) { }
 				} else {
 					throw me;
 				}
-			}
-			if (retryFlg) {
-				try {
-					m_log.debug("sendMail() : resend sleep (" + RETRY_SLEEP + ")");
-					Thread.sleep(RETRY_SLEEP);
-				} catch (InterruptedException e) {
-					m_log.warn("InterruptedException " + e.getMessage());
+			} finally {
+				if (transport != null) {
+					transport.close();
 				}
 			}
 		}
@@ -344,25 +329,24 @@ public class SendMail implements Notifier {
 	/**
 	 * 引数で指定された送信先アドレスの<code> InternetAddress </code>オブジェクトを返します。
 	 * 
-	 * @param address
+	 * @param addressList
 	 *            送信先アドレスの文字列配列
 	 * @return <code> InternetAddress </code>オブジェクトの配列
 	 */
-	private InternetAddress[] getAddress(String[] address) {
-
+	private InternetAddress[] getAddress(String[] addressList) {
 		InternetAddress toAddress[] = null;
 		Vector<InternetAddress> list = new Vector<InternetAddress>();
-
-		if (address != null) {
-
-			for (int index = 0; index < address.length; index++) {
+		if (addressList != null) {
+			for (String address : addressList) {
 				try {
-					list.add(new InternetAddress(address[index]));
-				} catch (AddressException ae) {
-					m_log.warn(ae.getMessage(), ae);
+					list.add(new InternetAddress(address));
+				} catch (AddressException e) {
+					m_log.info("getAddress() : "
+							+ e.getClass().getSimpleName() + ", "
+							+ address + ", "
+							+ e.getMessage());
 				}
 			}
-
 			if (list.size() > 0) {
 				toAddress = new InternetAddress[list.size()];
 				list.copyInto(toAddress);
@@ -379,31 +363,29 @@ public class SendMail implements Notifier {
 	 * @param mailInfo
 	 *            通知内容
 	 * @return メール件名
-	 * @throws CreateException
-	 * @throws NamingException
-	 * @throws FinderException
-	 * @throws RemoteException
 	 */
 	public String getSubject(OutputBasicInfo source,
-			NotifyMailInfoData mailInfo) {
+			NotifyMailInfoEntity mailInfo) {
 
 		String subject = null;
-
 		try {
-			if (mailInfo != null && mailInfo.getMailTemplateId() != null) {
-				MailTemplateInfo templateData = MailTemplateControllerUtil
-				.getLocalHome().create().getMailTemplateInfo(
-						mailInfo.getMailTemplateId());
-				Map<String, String> param = NotifyUtil.createParameter(source);
+			if (mailInfo != null
+					&& mailInfo.getMailTemplateInfoEntity() != null
+					&& mailInfo.getMailTemplateInfoEntity().getMailTemplateId() != null) {
+				MailTemplateInfo templateData
+				= new MailTemplateControllerBean().getMailTemplateInfo(
+						mailInfo.getMailTemplateInfoEntity().getMailTemplateId());
+				Map<String, String> param = NotifyUtil.createParameter(source, mailInfo.getNotifyInfoEntity());
 				StringBinder binder = new StringBinder(param);
 				subject = binder.bindParam(templateData.getSubject());
 			} else {
 				subject = Messages.getString("mail.subject", m_local) + "("
-				+ PriorityConstant.typeToString(source.getPriority())
-				+ ")";
+						+ PriorityConstant.typeToString(source.getPriority())
+						+ ")";
 			}
 		} catch (Exception e) {
-			m_log.warn(e.getMessage());
+			m_log.warn("getSubject() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			// 例外発生時のメールサブジェクト
 			return "Hinemos Notification";
 		}
@@ -419,22 +401,21 @@ public class SendMail implements Notifier {
 	 * @param mailInfo
 	 *            通知内容
 	 * @return メール本文
-	 * @throws CreateException
-	 * @throws NamingException
-	 * @throws FinderException
-	 * @throws RemoteException
 	 */
-	public String getContent(OutputBasicInfo source, NotifyMailInfoData mailInfo) {
+	public String getContent(OutputBasicInfo source, NotifyMailInfoEntity mailInfo) {
 
 		StringBuffer buf = new StringBuffer();
 		SimpleDateFormat sdf = new SimpleDateFormat(SUBJECT_DATE_FORMAT);
 
 		try {
-			if (mailInfo != null && mailInfo.getMailTemplateId() != null) {
-				MailTemplateInfo mailData = MailTemplateControllerUtil
-				.getLocalHome().create().getMailTemplateInfo(
-						mailInfo.getMailTemplateId());
-				Map<String, String> param = NotifyUtil.createParameter(source);
+			if (mailInfo != null
+					&& mailInfo.getMailTemplateInfoEntity() != null
+					&& mailInfo.getMailTemplateInfoEntity().getMailTemplateId() != null) {
+				MailTemplateInfo mailData
+				= new MailTemplateControllerBean().getMailTemplateInfo(
+						mailInfo.getMailTemplateInfoEntity().getMailTemplateId());
+				Map<String, String> param = NotifyUtil.createParameter(source,
+						mailInfo.getNotifyInfoEntity());
 				StringBinder binder = new StringBinder(param);
 				buf.append(binder.bindParam(mailData.getBody() + "\n"));
 			} else {
@@ -452,16 +433,17 @@ public class SendMail implements Notifier {
 						+ source.getScopeText() + "\n");
 			}
 		} catch (Exception e) {
-			m_log.warn(e.getMessage());
+			m_log.warn("getContent() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			// 例外発生時のメール本文
 			return "An error occurred creating message.";
 		}
-		
+
 		// 改行コードをLFからCRLFに変更する。
 		// 本来はJavaMailが変換するはずだが、変換されないこともあるので、
 		// 予め変更しておく。
 		String ret = buf.toString().replaceAll("\r\n", "\n").replaceAll("\n", "\r\n");
-		
+
 		return ret;
 	}
 
