@@ -29,11 +29,11 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Table;
 
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.repository.action.GetNodeList;
 import com.clustercontrol.repository.action.GetNodeListTableDefine;
 import com.clustercontrol.repository.util.RepositoryEndpointWrapper;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.repository.InvalidRole_Exception;
 import com.clustercontrol.ws.repository.NodeInfo;
 
@@ -64,25 +64,16 @@ public class NodeFilterComposite extends Composite {
 
 	/** スコープのファシリティID */
 	private String scopeId = null;
+	
+	/** 割り当て時はtrue, 解除時はfalse */
+	private boolean assignFlag = true;
 
 	// ----- コンストラクタ ----- //
 
 	/**
-	 * インスタンスを返します。
 	 * 
-	 * @param parent
-	 *            親のコンポジット
-	 * @param style
-	 *            スタイル
-	 */
-	public NodeFilterComposite(Composite parent, int style) {
-		super(parent, style);
-
-		this.initialize();
-	}
-
-	/**
-	 * 指定したスコープに属するノードを表示するインスタンスを返します。
+	 * 未割り当てノードを表示するインスタンスを返します。(割り当て時 assignFlag = true)
+	 * 指定したスコープに属するノードを表示するインスタンスを返します。(解除時 assignFlag = false)
 	 * <p>
 	 * 
 	 * このインスタンスは常に固定された内容を表示し、update(NodeFilterProperty) を実行しても表示内容に変更はありません。
@@ -94,9 +85,10 @@ public class NodeFilterComposite extends Composite {
 	 * @param facilityId
 	 *            スコープのファシリティID
 	 */
-	public NodeFilterComposite(Composite parent, int style, String facilityId) {
+	public NodeFilterComposite(Composite parent, int style, String facilityId, boolean assignFlag) {
 		super(parent, style);
 
+		this.assignFlag = assignFlag;
 		this.scopeId = facilityId;
 		this.initialize();
 	}
@@ -164,15 +156,48 @@ public class NodeFilterComposite extends Composite {
 	public void update() {
 		// データ取得
 		List<NodeInfo> list = null;
-		if (this.scopeId == null) {
+		if (assignFlag) {
+			List<NodeInfo> allList = null;
+			// 割り当て時
+			
+			// 全ノードを取得
 			if (this.condition == null) {
 				this.statuslabel.setText("");
-				list = new GetNodeList().getAll();
+				allList = new GetNodeList().getAll();
 			} else {
 				this.statuslabel.setText(Messages.getString("filtered.list"));
-				list = new GetNodeList().get(this.condition);
+				allList = new GetNodeList().get(this.condition);
+			}
+			
+			// 全ノードから既に割り当て済みのノードを取り除く。
+			try {
+				List<NodeInfo> assignedList = RepositoryEndpointWrapper.getNodeList(this.scopeId, 1);
+				list = new ArrayList<NodeInfo>();
+				for (NodeInfo node : allList) {
+					boolean flag = true;
+					for (NodeInfo assignedNode : assignedList) {
+						if (node.getFacilityId().equals(assignedNode.getFacilityId())) {
+							flag = false;
+							break;
+						}
+					}
+					if (flag) {
+						list.add(node);
+					}
+				}
+			} catch (InvalidRole_Exception e) {
+				// アクセス権なしの場合、エラーダイアログを表示する
+				MessageDialog.openInformation(null, Messages.getString("message"),
+						Messages.getString("message.accesscontrol.16"));
+			} catch (Exception e) {
+				m_log.warn("update(), " + e.getMessage(), e);
+				MessageDialog.openError(
+						null,
+						Messages.getString("failed"),
+						Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
 			}
 		} else {
+			// 割り当て解除時
 			this.statuslabel.setText("");
 			try {
 				// RepositoryControllerBean.ONE_LEVEL = 1
@@ -189,7 +214,6 @@ public class NodeFilterComposite extends Composite {
 						Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
 			}
 		}
-
 		ArrayList<Object> listInput = new ArrayList<Object>();
 		for (NodeInfo node : list) {
 			ArrayList<Object> a = new ArrayList<Object>();
@@ -202,6 +226,7 @@ public class NodeFilterComposite extends Composite {
 				a.add(node.getIpAddressV4());
 			}
 			a.add(node.getDescription());
+			a.add(node.getOwnerRoleId());
 			listInput.add(a);
 		}
 
@@ -211,7 +236,7 @@ public class NodeFilterComposite extends Composite {
 		// 合計欄更新
 		String[] args = { String.valueOf(list.size()) };
 		String message = null;
-		if (this.scopeId == null) {
+		if (assignFlag) {
 			if (this.condition == null) {
 				message = Messages.getString("records", args);
 			} else {
