@@ -23,7 +23,7 @@ import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.bean.PropertyConstant;
+import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.repository.bean.NodeFilterConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
@@ -61,41 +61,41 @@ public class NodeFilterProperty {
 
 		//ファシリティID
 		Property facilityId =
-			new Property(NodeFilterConstant.FACILITY_ID, Messages.getString("facility.id", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
+				new Property(NodeFilterConstant.FACILITY_ID, Messages.getString("facility.id", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
 		//ファシリティ名
 		Property facilityName =
-			new Property(NodeFilterConstant.FACILITY_NAME, Messages.getString("facility.name", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_256);
+				new Property(NodeFilterConstant.FACILITY_NAME, Messages.getString("facility.name", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_256);
 		//説明
 		Property description =
-			new Property(NodeFilterConstant.DESCRIPTION, Messages.getString("description", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
+				new Property(NodeFilterConstant.DESCRIPTION, Messages.getString("description", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
 		//IPアドレス v4
 		Property ipAddressV4 =
-			new Property(NodeFilterConstant.IP_ADDRESS_V4, Messages.getString("ip.address.v4", locale), PropertyConstant.EDITOR_IPV4);
+				new Property(NodeFilterConstant.IP_ADDRESS_V4, Messages.getString("ip.address.v4", locale), PropertyDefineConstant.EDITOR_IPV4);
 		//IPアドレス v6
 		Property ipAddressV6 =
-			new Property(NodeFilterConstant.IP_ADDRESS_V6, Messages.getString("ip.address.v6", locale), PropertyConstant.EDITOR_IPV6);
+				new Property(NodeFilterConstant.IP_ADDRESS_V6, Messages.getString("ip.address.v6", locale), PropertyDefineConstant.EDITOR_IPV6);
 		//OS名
 		Property osName =
-			new Property(NodeFilterConstant.OS_NAME, Messages.getString("os.name", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
+				new Property(NodeFilterConstant.OS_NAME, Messages.getString("os.name", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
 		//OSリリース
 		Property osRelease =
-			new Property(NodeFilterConstant.OS_RELEASE, Messages.getString("os.release", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
+				new Property(NodeFilterConstant.OS_RELEASE, Messages.getString("os.release", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
 		//管理者
 		Property administrator =
-			new Property(NodeFilterConstant.ADMINISTRATOR, Messages.getString("administrator", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
+				new Property(NodeFilterConstant.ADMINISTRATOR, Messages.getString("administrator", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
 		//連絡先
 		Property contact =
-			new Property(NodeFilterConstant.CONTACT, Messages.getString("contact", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
+				new Property(NodeFilterConstant.CONTACT, Messages.getString("contact", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
 
 		//ネットワーク
 		Property network =
-			new Property(NodeFilterConstant.NETWORK, Messages.getString("network", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
+				new Property(NodeFilterConstant.NETWORK, Messages.getString("network", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
 		//OS
 		Property os =
-			new Property(NodeFilterConstant.OS, Messages.getString("os", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
+				new Property(NodeFilterConstant.OS, Messages.getString("os", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
 		//保守
 		Property maintenance =
-			new Property(NodeFilterConstant.MAINTENANCE, Messages.getString("maintenance", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
+				new Property(NodeFilterConstant.MAINTENANCE, Messages.getString("maintenance", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
 
 		//値を初期化
 		facilityId.setValue("");
@@ -113,19 +113,19 @@ public class NodeFilterProperty {
 		maintenance.setValue("");
 
 		//変更の可/不可を設定
-		facilityId.setModify(PropertyConstant.MODIFY_OK);
-		facilityName.setModify(PropertyConstant.MODIFY_OK);
-		description.setModify(PropertyConstant.MODIFY_OK);
-		ipAddressV4.setModify(PropertyConstant.MODIFY_OK);
-		ipAddressV6.setModify(PropertyConstant.MODIFY_OK);
-		osName.setModify(PropertyConstant.MODIFY_OK);
-		osRelease.setModify(PropertyConstant.MODIFY_OK);
-		administrator.setModify(PropertyConstant.MODIFY_OK);
-		contact.setModify(PropertyConstant.MODIFY_OK);
+		facilityId.setModify(PropertyDefineConstant.MODIFY_OK);
+		facilityName.setModify(PropertyDefineConstant.MODIFY_OK);
+		description.setModify(PropertyDefineConstant.MODIFY_OK);
+		ipAddressV4.setModify(PropertyDefineConstant.MODIFY_OK);
+		ipAddressV6.setModify(PropertyDefineConstant.MODIFY_OK);
+		osName.setModify(PropertyDefineConstant.MODIFY_OK);
+		osRelease.setModify(PropertyDefineConstant.MODIFY_OK);
+		administrator.setModify(PropertyDefineConstant.MODIFY_OK);
+		contact.setModify(PropertyDefineConstant.MODIFY_OK);
 
-		os.setModify(PropertyConstant.MODIFY_NG);
-		network.setModify(PropertyConstant.MODIFY_NG);
-		maintenance.setModify(PropertyConstant.MODIFY_NG);
+		os.setModify(PropertyDefineConstant.MODIFY_NG);
+		network.setModify(PropertyDefineConstant.MODIFY_NG);
+		maintenance.setModify(PropertyDefineConstant.MODIFY_NG);
 
 		Property property = new Property(null, null, "");
 
